@@ -4,7 +4,7 @@ from __future__ import annotations
 import cmath
 from collections.abc import Iterable, Iterator
 from dataclasses import dataclass
-from typing import Literal, overload
+from typing import Literal, overload, TypeVar
 
 __all__ = ["Vector", "angle"]
 
@@ -47,6 +47,9 @@ def _iterable_to_complex(obj: Iterable[float], /) -> complex:
         return complex(x, y)
 
 
+TVector = TypeVar("TVector", bound="Vector")
+
+
 @dataclass(frozen=True, init=False, repr=False)
 class Vector:
     """A two-dimensional vector."""
@@ -81,7 +84,7 @@ class Vector:
                 ) from None
 
     @classmethod
-    def from_polar(cls, r: float, theta: float) -> Vector:
+    def from_polar(cls: type[TVector], r: float, theta: float) -> TVector:
         """Create a Vector from polar coordinates."""
         return cls(cmath.rect(r, theta))
 
